linchpin rise
=============

.. deprecated:: 1.0.0

This command is an alias for :doc:`linchpincli_linchpin_up`, and has been
included for backward compatibility with previous versions of linchpin. It will
be removed in a future version of linchpin.

Users of linchpin should switch to using ``linchpin up`` as soon as possible.
